
def configureSimulation(sim):
    import CompuCellSetup
    from XMLUtils import ElementCC3D
    
    CompuCell3DElmnt=ElementCC3D("CompuCell3D",{"version":"3.6.2"})
    
    PottsElmnt=CompuCell3DElmnt.ElementCC3D("Potts")
    
    # Basic properties of CPM (GGH) algorithm
    PottsElmnt.ElementCC3D("Dimensions",{"x":"50","y":"50","z":"1"})
    PottsElmnt.ElementCC3D("Steps",{},"10000")
    PottsElmnt.ElementCC3D("Temperature",{},"10.0")
    PottsElmnt.ElementCC3D("NeighborOrder",{},"1")
    
    PluginElmnt=CompuCell3DElmnt.ElementCC3D("Plugin",{"Name":"CellType"})
    
    # Listing all cell types in the simulation
    PluginElmnt.ElementCC3D("CellType",{"TypeId":"0","TypeName":"Medium"})
    PluginElmnt.ElementCC3D("CellType",{"TypeId":"1","TypeName":"Condensing"})
    
    PluginElmnt_1=CompuCell3DElmnt.ElementCC3D("Plugin",{"Name":"Volume"})
    PluginElmnt_1.ElementCC3D("VolumeEnergyParameters",{"CellType":"Condensing","LambdaVolume":"5.0","TargetVolume":"36"})
    
    PluginElmnt_1=CompuCell3DElmnt.ElementCC3D("Plugin",{"Name":"CenterOfMass"})
    
    # Module tracking center of mass of each cell
    
    PluginElmnt_2=CompuCell3DElmnt.ElementCC3D("Plugin",{"Name":"Contact"})
    # Specification of adhesion energies
    PluginElmnt_2.ElementCC3D("Energy",{"Type1":"Medium","Type2":"Medium"},"10.0")
    PluginElmnt_2.ElementCC3D("Energy",{"Type1":"Medium","Type2":"Condensing"},"10.0")
    PluginElmnt_2.ElementCC3D("Energy",{"Type1":"Condensing","Type2":"Condensing"},"10.0")
    PluginElmnt_2.ElementCC3D("NeighborOrder",{},"1")
    
    SteppableElmnt_1=CompuCell3DElmnt.ElementCC3D("Steppable",{"Type":"BlobInitializer"})
    
    RegionElmnt=SteppableElmnt_1.ElementCC3D("Region")
    RegionElmnt.ElementCC3D("Center",{"x":"25","y":"25","z":"0"})
    RegionElmnt.ElementCC3D("Radius",{},"2")
    RegionElmnt.ElementCC3D("Gap",{},"0")
    RegionElmnt.ElementCC3D("Width",{},"5")
    RegionElmnt.ElementCC3D("Types",{},"Condensing")

    CompuCellSetup.setSimulationXMLDescription(CompuCell3DElmnt)    

            
import sys
from os import environ
from os import getcwd
import string

sys.path.append(environ["PYTHON_MODULE_PATH"])


import CompuCellSetup


sim,simthread = CompuCellSetup.getCoreSimulationObjects()
        
configureSimulation(sim)            
                
# add extra attributes here
        
pyAttributeDictionaryAdder,dictAdder=CompuCellSetup.attachDictionaryToCells(sim)
            
CompuCellSetup.initializeSimulationObjects(sim,simthread)
# Definitions of additional Python-managed fields go here
        
#Add Python steppables here
steppableRegistry=CompuCellSetup.getSteppableRegistry()
        
from CellCycleSteppables import CellCycleSteppable
steppableInstance=CellCycleSteppable(sim,_frequency=1)
steppableRegistry.registerSteppable(steppableInstance)

from CellCycleSteppables import VisualizationField
instanceOfVisualizationField=VisualizationField(_simulator=sim,_frequency=1)
steppableRegistry.registerSteppable(instanceOfVisualizationField)

from CellCycleSteppables import Mitosis
instanceOfMitosis=Mitosis(_simulator=sim,_frequency=1)
steppableRegistry.registerSteppable(instanceOfMitosis)

CompuCellSetup.mainLoop(sim,simthread,steppableRegistry)
        
        
       